#include "Sound.h"
#include <QString>
#include <QSound>
#include <QtDebug>
#include <macros.h>

Sound::Sound(const QString& sound_file)
{
    m_init(sound_file);
}

Sound::Sound(QObject *parent, const QString &sound_file) : QObject(parent)
{
   m_init(sound_file);
}

void Sound::m_init(const QString& sound_file)
{
    mSoundEffect.setSource(QUrl::fromLocalFile(sound_file));
    set_loop_delay(500);
    m_loop_timer.setSingleShot(true);
    m_loop_enabled = false;
    connect(&mSoundEffect, SIGNAL(playingChanged()), this, SLOT(playingChanged()));
    connect(&m_loop_timer, SIGNAL(timeout()), &mSoundEffect, SLOT(play()));
}

void Sound::play()
{
    if (m_loop_enabled) return;
    mSoundEffect.play();
}

void Sound::loop()
{
    if(!m_loop_enabled){
        m_loop_enabled = true;
        mSoundEffect.play();
    }
}

void Sound::playingChanged()
{
    if(m_loop_enabled && !mSoundEffect.isPlaying())
        m_loop_timer.start();
}

void Sound::stop()
{
    m_loop_enabled = false;
    m_loop_timer.stop();
    mSoundEffect.stop();
}

void Sound::set_loop_delay(int delay)
{
    m_loop_timer.setInterval(delay);
}

int  Sound::get_loop_delay()
{
    return m_loop_timer.interval();
}

void Sound::timer_timeout() {
    mSoundEffect.play();
}

